@@ -32,9 +32,7 @@ rep_rows <- function(x, i) {
 #' @param w Optional case weights.
 #' @returns A (1 x ncol(x)) matrix of column means.
 wcolMeans <- function(x, w = NULL, ...) {
-  if (!is.matrix(x)) {
-    x <- as.matrix(x)
-  }
+  x <- as.matrix(x)
   out <- if (is.null(w)) colMeans(x) else colSums(x * w) / sum(w)
   t.default(out)
 }
@@ -89,15 +87,9 @@ get_vz <- function(X, bg, Z, object, pred_fun, w, ...) {
       X[[v]][s] <- bg[[v]][s]
     }
   }
-  preds <- align_pred(pred_fun(object, X, ...), ohe = FALSE)
+  preds <- align_pred(pred_fun(object, X, ...))
   
-  # Aggregate (distinguishing some faster cases)
-  if (is.factor(preds)) {
-    if (is.null(w)) {
-      return(rowmean_factor(preds, ngroups = m))
-    }
-    preds <- fdummy(preds)
-  }
+  # Aggregate (distinguishing fast 1-dim case)
   if (ncol(preds) == 1L) {
     return(wrowmean_vector(preds, ngroups = m, w = w))
   }
@@ -148,7 +140,7 @@ reorganize_list <- function(alist) {
   lapply(out, as.matrix)
 }
 
-#' Aligns Predictions (adapted from {hstats})
+#' Aligns Predictions
 #'
 #' Turns predictions into matrix.
 #'
@@ -156,16 +148,18 @@ reorganize_list <- function(alist) {
 #' @keywords internal
 #'
 #' @param x Object representing model predictions.
-#' @param ohe If `x` is a factor: should it be one-hot encoded? Default is `TRUE`.
-#' @returns Like `x`, but converted to matrix (or a factor).
-align_pred <- function(x, ohe = TRUE) {
+#' @returns Like `x`, but converted to matrix.
+align_pred <- function(x) {
   if (is.data.frame(x) && ncol(x) == 1L) {
     x <- x[[1L]]
   }
-  if (ohe && is.factor(x)) {
-    return(fdummy(x))
+  if (!is.matrix(x)) {
+    x <- as.matrix(x)
   }
-  if (is.matrix(x) || is.factor(x)) x else as.matrix(x)
+  if (!is.numeric(x) && !is.logical(x)) {
+    stop("Predictions must be numeric!")
+  }
+  return(x)
 }
 
 #' Head of List Elements
@@ -252,28 +246,6 @@ rep_each <- function(m, each) {
   out 
 }
 
-#' Fast OHE (from {hstats})
-#' 
-#' Turns vector/factor into its One-Hot-Encoding.
-#' Ingeniouly written by Mathias Ambuehl.
-#' 
-#' Working with integers instead of doubles would be slightly faster, but at the price
-#' of potential integer overflows in subsequent calculations.
-#' 
-#' @noRd
-#' @keywords internal
-#' 
-#' @param x Object representing model predictions.
-#' @returns Like `x`, but converted to matrix.
-fdummy <- function(x) {
-  x <- as.factor(x)
-  lev <- levels(x)
-  out <- matrix(0, nrow = length(x), ncol = length(lev))
-  out[cbind(seq_along(x), as.integer(x))] <- 1
-  colnames(out) <- lev
-  out 
-}
-
 #' Grouped Means for Single-Column Matrices (adapted from {hstats})
 #'
 #' Grouped means for matrix with single column over fixed-length groups.
@@ -299,26 +271,6 @@ wrowmean_vector <- function(x, ngroups = 1L, w = NULL) {
   out
 }
 
-#' rowmean_vector() for factors (copied from {hstats})
-#'
-#' Grouped `colMeans_factor()` for equal sized groups.
-#'
-#' @noRd
-#' @keywords internal
-#'
-#' @param x Factor-like.
-#' @param ngroups Number of subsequent, equals sized groups.
-#' @returns Matrix with column names.
-rowmean_factor <- function(x, ngroups = 1L) {
-  x <- as.factor(x)
-  lev <- levels(x)
-  n_bg <- length(x) %/% ngroups
-  dim(x) <- c(n_bg, ngroups)
-  out <- t.default(apply(x, 2L, FUN = tabulate, nbins = length(lev)))
-  colnames(out) <- lev
-  out / n_bg
-}
-
 #' Basic Input Checks
 #' 
 #' @noRd
